]> sjero.net Git - wget/blobdiff - src/url.h
[svn] Various url.c-related changes.
[wget] / src / url.h
index 02ea9ca54fbe9d11368e042b44260a9ee8a3d25b..a180cc6e24534f3a16f1e0627280dc1f4958ae54 100644 (file)
--- a/src/url.h
+++ b/src/url.h
@@ -20,9 +20,11 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #ifndef URL_H
 #define URL_H
 
-/* If the string contains unsafe characters, duplicate it with
-   encode_string, otherwise just copy it with strdup.  */
-#define CLEANDUP(x) (contains_unsafe (x) ? encode_string (x) : xstrdup (x))
+/* Default port definitions */
+#define DEFAULT_HTTP_PORT 80
+#define DEFAULT_FTP_PORT 21
+#define DEFAULT_HTTPS_PORT 443
+
 
 /* Structure containing info on a URL.  */
 struct urlinfo
@@ -44,23 +46,35 @@ struct urlinfo
                                   document */
 };
 
-enum uflags
-{
-  URELATIVE     = 0x0001,      /* Is URL relative? */
-  UNOPROTO      = 0x0002,      /* Is URL without a protocol? */
-  UABS2REL      = 0x0004,      /* Convert absolute to relative? */
-  UREL2ABS      = 0x0008       /* Convert relative to absolute? */
+enum convert_options {
+  CO_NOCONVERT = 0,            /* don't convert this URL */
+  CO_CONVERT_TO_RELATIVE,      /* convert to relative, e.g. to
+                                   "../../otherdir/foo.gif" */
+  CO_CONVERT_TO_COMPLETE       /* convert to absolute, e.g. to
+                                  "http://orighost/somedir/bar.jpg". */
 };
 
 /* A structure that defines the whereabouts of a URL, i.e. its
    position in an HTML document, etc.  */
+
 typedef struct _urlpos
 {
-  char *url;                   /* URL */
-  char *local_name;            /* Local file to which it was saved */
-  enum uflags flags;           /* Various flags */
-  int pos, size;               /* Relative position in the buffer */
-  struct _urlpos *next;        /* Next struct in list */
+  char *url;                   /* linked URL, after it has been
+                                  merged with the base */
+  char *local_name;            /* Local file to which it was saved */
+
+  /* Information about the original link: */
+  int link_relative_p;         /* was the link relative? */
+  int link_complete_p;         /* was the link complete (with the
+                                   host name, etc.) */
+
+  /* Conversion requirements: */
+  enum convert_options convert;        /* is conversion required? */
+
+  /* URL's position in the buffer. */
+  int pos, size;
+
+  struct _urlpos *next;                /* Next struct in list */
 } urlpos;
 
 /* downloaded_file() takes a parameter of this type and returns this type. */
@@ -79,15 +93,13 @@ typedef enum
 
 /* Function declarations */
 
-int skip_url PARAMS ((const char *));
-
-int contains_unsafe PARAMS ((const char *));
 char *encode_string PARAMS ((const char *));
 
 struct urlinfo *newurl PARAMS ((void));
 void freeurl PARAMS ((struct urlinfo *, int));
 uerr_t urlproto PARAMS ((const char *));
 int skip_proto PARAMS ((const char *));
+int has_proto PARAMS ((const char *));
 int skip_uname PARAMS ((const char *));
 
 uerr_t parseurl PARAMS ((const char *, struct urlinfo *, int));
@@ -95,9 +107,11 @@ char *str_url PARAMS ((const struct urlinfo *, int));
 int url_equal PARAMS ((const char *, const char *));
 
 urlpos *get_urls_file PARAMS ((const char *));
-urlpos *get_urls_html PARAMS ((const char *, const char *, int, int));
+urlpos *get_urls_html PARAMS ((const char *, const char *, int, int *));
 void free_urlpos PARAMS ((urlpos *));
 
+char *uri_merge PARAMS ((const char *, const char *));
+
 void rotate_backups PARAMS ((const char *));
 int mkalldirs PARAMS ((const char *));
 char *url_filename PARAMS ((const struct urlinfo *));